::: graphium.finetuning.fingerprinting.Fingerprinter
    options: 
        filters: ["!^_"]
        separate_signature: true
        show_signature_annotations: true
        line_length: 80
        merge_init_into_class: true 
        members_order: source